#!/bin/sh

# Modifiy the following variable to your needs.
prefix=/usr/local/cross-tools

target=m68k-atari-mint
export PATH=$prefix/bin:$PATH
export LD_LIBRARY_PATH=$prefix/lib:$LD_LIBRARY_PATH

HAS_GCC33=`gcc -v 2>&1 | grep "version 3.3"`
if [ -z "$HAS_GCC33" ]; then
    echo "ERROR: you need gcc 3.3 to use this script"
    echo "Please update your gcc version from ADC member site (http://connect.apple.com)"
    exit 1
fi;


create_dir() {
    mkdir -pv "$1"
    if [ $? -ne 0 ]; then
		echo "Error while creating '$1'. Probably you don't have the right permissions."
		echo "Trying with admin rights (sudo). Please enter administrator password."
		
		sudo mkdir -pv "$1"
		if [ $? -ne 0 ]; then
			echo "Still an error. Aborting."
			echo "Please create directory '$1' manually."
			return 1
		fi;
		sudo chown $USER:$GROUPS "$1"
    fi;
    return 0
}

check_file() {
	if [ ! -f "$1" ]; then
		echo "File $1 not found. Abort"
		return 1
	fi
	return 0
}

do_process() {
    case $1 in
	(create-dirs)
		echo "*** Creating directories ***"
		create_dir $prefix
		if [ $? -ne 0 ]; then
			return 1
		fi;
		
		create_dir $prefix/m68k-atari-mint/
		if [ $? -ne 0 ]; then
			return 1
		fi;
		echo "*** Creating directories done ***"
		return 0
		;;
	
	(prepare-Xcode)
		echo "*** preparing Xcode ***"
		xcode_dir="/Library/Application Support/Apple/Developer Tools/"
		create_dir "$xcode_dir"
		if [ $? -ne 0 ]; then
			echo "Xcode support could not be installed."
		fi;
		if [ -d "$xcode_dir" ]; then
			cp -r "Project Templates" "$xcode_dir"
		fi;
		echo "*** preparing Xcode done ***"
		return 0
		;;

	(extract-mintlib)
		check_file mintlib-devel-cvs-20041122-binary.tar.gz
		if [ $? -ne 0 ]; then
			return 1
		fi;
		
		echo "*** extracting mintlib-devel ***"
		tar xvzf mintlib-devel-cvs-20041122-binary.tar.gz && \
		mv include lib $prefix/m68k-atari-mint/
		if [ $? -ne 0 ]; then
			echo "ERROR while extracting mintlib-devel"
			return 1
		fi;
		echo "*** moved mintlib-devel to $prefix/m68k-atari-mint/ ***"
		return 0
		;;

	(extract-binutils)
		check_file binutils-2.13.2.1.tar.gz
		if [ $? -ne 0 ]; then
			return 1
		fi;

		echo "*** extracting binutils ***"
		tar xvzf binutils-2.13.2.1.tar.gz
		if [ $? -ne 0 ]; then
			echo "ERROR while extracting binutils"
			return 1
		fi;
		echo "*** extracting binutils done ***"
		return 0
		;;

	(patch-binutils)
		echo "*** patching binutils for MiNT ***"
		cd binutils-2.13.2.1 && \
		gunzip -c ../binutils-2.13.2.1-mint-2.diff.gz | patch -p1 && \
		cd ..
		if [ $? -ne 0 ]; then
			return 1
		fi;
		echo "*** patching binutils for MiNT done ***"
		return 0
		;;

	(build-binutils)
		echo "*** building binutils ***"
		mkdir binutils-2.13.2.1-mint && \
		cd binutils-2.13.2.1-mint && \
		../binutils-2.13.2.1/configure --prefix=$prefix --target=$target && \
		make && make install && \
		cd ..
		if [ $? -ne 0 ]; then
			return 1
		fi
		echo "*** building binutils done ***"
		return 0
		;;

	(extract-gcc)
		check_file gcc-3.3.3.tar.gz
		if [ $? -ne 0 ]; then
			return 1
		fi;

		echo "*** extracting gcc sources ***"
		tar xvzf gcc-3.3.3.tar.gz
		if [ $? -ne 0 ]; then
			return 1
		fi
		echo "*** extracting gcc sources done ***"
		return 0
		;;

	(patch-gcc)
		echo "*** patching gcc sources for MiNT ***"
		cd gcc-3.3.3 && \
		gunzip -c ../gcc-3.3.3-mint.diff.gz | patch -p1 && \
		cd ..
		if [ $? -ne 0 ]; then
			return 1
		fi
		echo "*** patching gcc sources for MiNT done ***"
		return 0
		;;

	(configure-gcc)
		echo "*** configuring gcc for MiNT ***"
		mkdir gcc-3.3.3-mint && \
		cd gcc-3.3.3-mint && \
		../gcc-3.3.3/configure --prefix=$prefix --target=$target --enable-languages=c++ && \
		cd ..
		if [ $? -ne 0 ]; then
			return 1
		fi
		echo "*** configuring gcc for MiNT done ***"
		return 0
		;;

	(compile-gcc)
		echo "*** compiling gcc for MiNT ***"
		cd gcc-3.3.3-mint && \
		make all install && \
		cd ..
		if [ $? -ne 0 ]; then
			return 1;
		fi
		echo "*** compiling gcc for MiNT done ***"
		return 0
		;;
	
    esac

    return 1
}



# List of tasks...
TASKS="create-dirs prepare-Xcode extract-mintlib extract-binutils patch-binutils build-binutils extract-gcc patch-gcc configure-gcc compile-gcc"
STARTTASK=create-dirs

if [ $# -eq 1 ]; then
    FOUND=0
    for T in $TASKS ; do
		if [ $T == $1 ]; then
			FOUND=1
			STARTTASK=$T
			break
		fi;
    done
    if [ $FOUND -ne 1 ]; then
		echo "'$1' is an invalid task name."
		echo "Use one of these: "
		echo "  $TASKS"
		
		exit
    fi;
fi

PROCESS=0
for T in $TASKS ; do
    if [ $T == $STARTTASK ]; then
		PROCESS=1
    fi
    if [ $PROCESS -eq 1 ]; then
		echo "**** Processing task $T"
		do_process $T
		if [ $? -ne 0 ]; then
			echo "**** Error while processing task $T."
			echo "**** Correct the error and restart task $T with:"
			echo "****      $0 $T"
			exit
		fi;
    fi
done

echo "************** done **************"
echo "The cross-compiler was installed in $prefix."
echo "To use it, make sure you set"
echo "        PATH=$prefix/bin:\$PATH"
echo "        LD_LIBRARY_PATH=$prefix/lib:\$LD_LIBRARY_PATH"

exit




